DateTimeTool class

Tools for dealing with date and time objects in the app and the Philips Hue system.

Constructors

DateTimeTool()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

dateOnly(DateTime date) → DateTime
Returns a DateTime with the date of the original, but time set to midnight.
toHueString(DateTime dateTime) → String
Converts the given dateTime to a string that the Hue bridge can understand.